import random


def random_one(messages):
    return random.choice(messages)


def first(messages):
    return messages[0]


def nop(message):
    return message
